@@ -3,6 +3,7 @@
 package tui
 
 import (
+	"bytes"
 	"testing"
 
 	"github.com/dundee/gdu/v5/internal/testapp"
@@ -16,7 +17,7 @@ func TestShowDevicesWithError(t *testing.T) {
 
 	getter := device.LinuxDevicesInfoGetter{MountsPath: "/xyzxyz"}
 
-	ui := CreateUI(app, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false)
 	err := ui.ListDevices(getter)
 
 	assert.Contains(t, err.Error(), "no such file")
