@@ -71,12 +71,12 @@ func TestDeviceSelected(t *testing.T) {
 
 	<-ui.done // wait for analyzer
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
-
 	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
 		f()
 	}
 
+	assert.Equal(t, "test_dir", ui.currentDir.Name)
+
 	assert.Equal(t, 5, ui.table.GetRowCount())
 	assert.Contains(t, ui.table.GetCell(0, 0).Text, "/..")
 	assert.Contains(t, ui.table.GetCell(1, 0).Text, "aaa")
@@ -117,13 +117,13 @@ func TestAnalyzePathWithParentDir(t *testing.T) {
 
 	<-ui.done // wait for analyzer
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
-	assert.Equal(t, parentDir, ui.currentDir.Parent)
-
 	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
 		f()
 	}
 
+	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, parentDir, ui.currentDir.Parent)
+
 	assert.Equal(t, 5, ui.table.GetRowCount())
 	assert.Contains(t, ui.table.GetCell(0, 0).Text, "/..")
 	assert.Contains(t, ui.table.GetCell(1, 0).Text, "aaa")
@@ -145,11 +145,11 @@ func TestReadAnalysis(t *testing.T) {
 
 	<-ui.done // wait for reading
 
-	assert.Equal(t, "gdu", ui.currentDir.Name)
-
 	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
 		f()
 	}
+
+	assert.Equal(t, "gdu", ui.currentDir.Name)
 }
 
 func TestReadAnalysisWithWrongFile(t *testing.T) {
@@ -188,16 +188,29 @@ func TestViewDirContents(t *testing.T) {
 
 	<-ui.done // wait for analyzer
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
-
 	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
 		f()
 	}
 
+	assert.Equal(t, "test_dir", ui.currentDir.Name)
+
 	res := ui.showFile() // selected item is dir, do nothing
 	assert.Nil(t, res)
 }
 
+func TestViewFileWithoutCurrentDir(t *testing.T) {
+	simScreen := testapp.CreateSimScreen(50, 50)
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(true)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true)
+	ui.Analyzer = &testanalyze.MockedAnalyzer{}
+	ui.done = make(chan struct{})
+
+	res := ui.showFile() // no current directory
+	assert.Nil(t, res)
+}
+
 func TestViewContentsOfNotExistingFile(t *testing.T) {
 	simScreen := testapp.CreateSimScreen(50, 50)
 	defer simScreen.Fini()
@@ -211,12 +224,12 @@ func TestViewContentsOfNotExistingFile(t *testing.T) {
 
 	<-ui.done // wait for analyzer
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
-
 	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
 		f()
 	}
 
+	assert.Equal(t, "test_dir", ui.currentDir.Name)
+
 	ui.table.Select(3, 0)
 
 	selectedFile := ui.table.GetCell(3, 0).GetReference().(analyze.Item)
@@ -240,12 +253,12 @@ func TestViewFile(t *testing.T) {
 
 	<-ui.done // wait for analyzer
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
-
 	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
 		f()
 	}
 
+	assert.Equal(t, "test_dir", ui.currentDir.Name)
+
 	ui.table.Select(0, 0)
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0))
 	ui.table.Select(2, 0)
@@ -271,12 +284,12 @@ func TestShowInfo(t *testing.T) {
 
 	<-ui.done // wait for analyzer
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
-
 	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
 		f()
 	}
 
+	assert.Equal(t, "test_dir", ui.currentDir.Name)
+
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0))
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'i', 0))
 	ui.table.Select(2, 0)
@@ -303,12 +316,12 @@ func TestShowInfoBW(t *testing.T) {
 
 	<-ui.done // wait for analyzer
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
-
 	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
 		f()
 	}
 
+	assert.Equal(t, "test_dir", ui.currentDir.Name)
+
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0))
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'i', 0))
 	ui.table.Select(2, 0)
@@ -317,6 +330,21 @@ func TestShowInfoBW(t *testing.T) {
 	assert.True(t, ui.pages.HasPage("info"))
 }
 
+func TestShowInfoWithoutCurrentDir(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+	simScreen := testapp.CreateSimScreen(50, 50)
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(true)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true)
+	ui.done = make(chan struct{})
+
+	// pressing `i` will do nothing
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'i', 0))
+	assert.False(t, ui.pages.HasPage("info"))
+}
+
 func TestExitViewFile(t *testing.T) {
 	fin := testdir.CreateTestDir()
 	defer fin()
@@ -331,12 +359,12 @@ func TestExitViewFile(t *testing.T) {
 
 	<-ui.done // wait for analyzer
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
-
 	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
 		f()
 	}
 
+	assert.Equal(t, "test_dir", ui.currentDir.Name)
+
 	ui.table.Select(0, 0)
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0))
 	ui.table.Select(2, 0)
