@@ -164,12 +164,14 @@ func (ui *UI) spawnShell() {
 		return
 	}
 
-	ui.app.Stop()
-	if err := os.Chdir(ui.currentDirPath); err != nil {
-		ui.showErr("Error changing directory", err)
-		return
-	}
-	if err := ui.exec(getShellBin(), nil, os.Environ()); err != nil {
-		ui.showErr("Error executing shell", err)
-	}
+	ui.app.Suspend(func() {
+		if err := os.Chdir(ui.currentDirPath); err != nil {
+			ui.showErr("Error changing directory", err)
+			return
+		}
+
+		if err := ui.exec(getShellBin(), nil, os.Environ()); err != nil {
+			ui.showErr("Error executing shell", err)
+		}
+	})
 }
